Internal helper that checks whether bcftools can be executed.
It runs bcftools.path --version and errors if the command fails.
Internal helper that checks whether bcftools can be executed.
It runs bcftools.path --version and errors if the command fails.