Transform a strataG gtypes object into a tidy data frame. Used internally in genometranslator and might be of interest for users.
Dependencies
Required package dependencies are declared in DESCRIPTION and installed
with genometranslator. Run genometranslator_dependencies() to inspect
core packages, optional packages, and external executables.
gtypes support requires the optional GitHub package
strataG. Consult its
repository for current installation and troubleshooting information.
References
Archer FI, Adams PE, Schneiders BB. strataG: An r package for manipulating, summarizing and analysing population genetic data. Molecular Ecology Resources. 2017; 17: 5-11. doi:10.1111/1755-0998.12559
Author
Thierry Gosselin thierrygosselin@icloud.com